@@ -12,14 +12,12 @@ else:
     setapi('QString', 2)
     setapi('QVariant', 2)
 
-import logging
-try:
-    from logging import NullHandler
-except ImportError:  # python 2.6 workaround
-    class NullHandler(logging.Handler):
+import sys
+from ._mpl_backend import MatplotlibBackendSetter
+sys.meta_path.append(MatplotlibBackendSetter())
 
-        def emit(self, record):
-            pass
+import logging
+from logging import NullHandler
 
 logging.getLogger('glue').addHandler(NullHandler())
 
@@ -93,10 +91,10 @@ def custom_viewer(name, **kwargs):
         passed to viewer functions.
       * ``keyword='att(foo)'`` doesn't create any widget, but passes
         in the attribute named ``foo`` to the viewer functions, as an
-        :class:`~glue.qt.custom_viewer.AttributeInfo` object.
+        :class:`~glue.viewers.custom.qt.custom_viewer.AttributeInfo` object.
       * ``keyword='att'`` creates a dropdown to let the user select
         one of the attributes from the data. The selected attribute
-        is passed as an :class:`~glue.qt.custom_viewer.AttributeInfo`
+        is passed as an :class:`~glue.viewers.custom.qt.custom_viewer.AttributeInfo`
 
     **Viewer Functions**
 
@@ -117,7 +115,7 @@ def custom_viewer(name, **kwargs):
     """
 
     # delay Qt import until needed
-    from .qt.custom_viewer import CustomViewer
+    from .viewers.custom.qt import CustomViewer
     return CustomViewer.create_new_subclass(name, **kwargs)
 
 # Load user's configuration file
@@ -133,7 +131,23 @@ from .main import load_plugins
 def test(no_optional_skip=False):
     from pytest import main
     root = os.path.abspath(os.path.dirname(__file__))
-    args = [root]
+    args = [root, '-x']
     if no_optional_skip:
         args.append('--no-optional-skip')
-    main(args=args)
+    return main(args=args)
+
+from glue._settings_helpers import load_settings
+load_settings()
+
+
+# In PyQt 5.5+, PyQt overrides the default exception catching and fatally
+# crashes the Qt application without printing out any details about the error.
+# Below we revert the exception hook to the original Python one. Note that we
+# can't just do sys.excepthook = sys.__excepthook__ otherwise PyQt will detect
+# the default excepthook is in place and override it.
+
+
+def handle_exception(exc_type, exc_value, exc_traceback):
+    sys.__excepthook__(exc_type, exc_value, exc_traceback)
+
+sys.excepthook = handle_exception
