@@ -6,7 +6,7 @@ class MatplotlibBackendSetter(object):
 
     enabled = True
 
-    def find_module(self, mod_name, pth):
+    def find_module(self, mod_name, pth=None):
         if self.enabled and 'matplotlib' in mod_name:
             self.enabled = False
             set_mpl_backend()
@@ -16,13 +16,19 @@ class MatplotlibBackendSetter(object):
 
 def set_mpl_backend():
 
+    try:
+        from qtpy import PYQT5
+    except:
+        # If Qt isn't available, we don't have to worry about
+        # setting the backend
+        return
+
     from matplotlib import rcParams, rcdefaults
 
     # standardize mpl setup
     rcdefaults()
 
-    from glue.external.qt import is_pyqt5
-    if is_pyqt5():
+    if PYQT5:
         rcParams['backend'] = 'Qt5Agg'
     else:
         rcParams['backend'] = 'Qt4Agg'
