@@ -7,29 +7,31 @@ import sys
 import warnings
 import webbrowser
 
-from glue.external.qt.QtCore import Qt
-from glue.external.qt import QtGui, QtCore
+from qtpy import QtCore, QtWidgets, QtGui, compat
+from qtpy.QtCore import Qt
+
 from glue.core.application_base import Application
 from glue.core import command, Data
 from glue import env
 from glue.main import load_plugins
 from glue.icons.qt import get_icon
-from glue.external.qt import get_qapp
+from glue.utils.qt import get_qapp
 from glue.app.qt.actions import action
 from glue.dialogs.data_wizard.qt import data_wizard
 from glue.app.qt.edit_subset_mode_toolbar import EditSubsetModeToolBar
 from glue.app.qt.mdi_area import GlueMdiArea, GlueMdiSubWindow
 from glue.app.qt.layer_tree_widget import PlotAction, LayerTreeWidget
-from glue.app.qt.settings_editor import SettingsEditor
+from glue.app.qt.preferences import PreferencesDialog
 from glue.viewers.common.qt.mpl_widget import defer_draw
 from glue.viewers.common.qt.data_viewer import DataViewer
 from glue.viewers.image.qt import ImageWidget
 from glue.viewers.scatter.qt import ScatterWidget
 from glue.utils import nonpartial
-from glue.utils.qt import (pick_class, GlueTabBar, QMessageBoxPatched as
-                           QMessageBox, set_cursor, messagebox_on_error, load_ui)
+from glue.utils.qt import (pick_class, GlueTabBar,
+                           QMessageBoxPatched as QMessageBox,
+                           set_cursor_cm, messagebox_on_error, load_ui)
 
-from glue.app.qt.feedback import submit_bug_report
+from glue.app.qt.feedback import submit_bug_report, submit_feedback
 from glue.app.qt.plugin_manager import QtPluginManager
 from glue.app.qt.versions import show_glue_info
 
@@ -73,10 +75,10 @@ def status_pixmap(attention=False):
     return pm
 
 
-class ClickableLabel(QtGui.QLabel):
+class ClickableLabel(QtWidgets.QLabel):
 
     """
-    A QtGui.QLabel you can click on to generate events
+    A QtWidgets.QLabel you can click on to generate events
     """
 
     clicked = QtCore.Signal()
@@ -85,7 +87,7 @@ class ClickableLabel(QtGui.QLabel):
         self.clicked.emit()
 
 
-class GlueLogger(QtGui.QWidget):
+class GlueLogger(QtWidgets.QWidget):
 
     """
     A window to display error messages
@@ -93,13 +95,13 @@ class GlueLogger(QtGui.QWidget):
 
     def __init__(self, parent=None):
         super(GlueLogger, self).__init__(parent)
-        self._text = QtGui.QTextEdit()
+        self._text = QtWidgets.QTextEdit()
         self._text.setTextInteractionFlags(Qt.TextSelectableByMouse)
 
-        clear = QtGui.QPushButton("Clear")
+        clear = QtWidgets.QPushButton("Clear")
         clear.clicked.connect(nonpartial(self._clear))
 
-        report = QtGui.QPushButton("Send Bug Report")
+        report = QtWidgets.QPushButton("Send Bug Report")
         report.clicked.connect(nonpartial(self._send_report))
 
         self.stderr = sys.stderr
@@ -111,8 +113,8 @@ class GlueLogger(QtGui.QWidget):
         self._status.setPixmap(status_pixmap())
         self._status.setContentsMargins(0, 0, 0, 0)
 
-        l = QtGui.QVBoxLayout()
-        h = QtGui.QHBoxLayout()
+        l = QtWidgets.QVBoxLayout()
+        h = QtWidgets.QHBoxLayout()
         l.setContentsMargins(2, 2, 2, 2)
         l.setSpacing(2)
         h.setContentsMargins(0, 0, 0, 0)
@@ -152,8 +154,7 @@ class GlueLogger(QtGui.QWidget):
         Send the contents of the log as a bug report
         """
         text = self._text.document().toPlainText()
-        if submit_bug_report(text):
-            self._clear()
+        submit_bug_report(text)
 
     def _clear(self):
         """
@@ -178,15 +179,15 @@ class GlueLogger(QtGui.QWidget):
             self.hide()
 
 
-class GlueApplication(Application, QtGui.QMainWindow):
+class GlueApplication(Application, QtWidgets.QMainWindow):
 
     """ The main GUI application for the Qt frontend"""
 
-    def __init__(self, data_collection=None, session=None):
+    def __init__(self, data_collection=None, session=None, maximized=True):
 
         self.app = get_qapp()
 
-        QtGui.QMainWindow.__init__(self)
+        QtWidgets.QMainWindow.__init__(self)
         Application.__init__(self, data_collection=data_collection,
                              session=session)
 
@@ -217,15 +218,13 @@ class GlueApplication(Application, QtGui.QMainWindow):
         lwidget.ui.layerTree.addAction(a)
         lwidget.bind_selection_to_edit_subset()
 
-        self._tweak_geometry()
+        self._tweak_geometry(maximized=maximized)
         self._create_actions()
         self._create_menu()
         self._connect()
         self.new_tab()
         self._update_plot_dashboard(None)
 
-        self._load_settings()
-
     def _setup_ui(self):
         self._ui = load_ui('application.ui', None,
                            directory=os.path.dirname(__file__))
@@ -234,7 +233,7 @@ class GlueApplication(Application, QtGui.QMainWindow):
 
         lw = LayerTreeWidget()
         lw.set_checkable(False)
-        self._vb = QtGui.QVBoxLayout()
+        self._vb = QtWidgets.QVBoxLayout()
         self._vb.setContentsMargins(0, 0, 0, 0)
         self._vb.addWidget(lw)
         self._ui.data_layers.setLayout(self._vb)
@@ -248,9 +247,10 @@ class GlueApplication(Application, QtGui.QMainWindow):
         self.statusBar().setContentsMargins(2, 0, 20, 2)
         self.statusBar().setSizeGripEnabled(False)
 
-    def _tweak_geometry(self):
-        """Maximize window"""
-        self.setWindowState(Qt.WindowMaximized)
+    def _tweak_geometry(self, maximized=True):
+        """Maximize window by default."""
+        if maximized:
+            self.setWindowState(Qt.WindowMaximized)
         self._ui.main_splitter.setSizes([100, 800])
         self._ui.data_plot_splitter.setSizes([100, 150, 250])
 
@@ -280,7 +280,7 @@ class GlueApplication(Application, QtGui.QMainWindow):
 
     def new_tab(self):
         """Spawn a new tab page"""
-        layout = QtGui.QGridLayout()
+        layout = QtWidgets.QGridLayout()
         layout.setSpacing(1)
         layout.setContentsMargins(0, 0, 0, 0)
         widget = GlueMdiArea(self)
@@ -300,11 +300,11 @@ class GlueApplication(Application, QtGui.QMainWindow):
 
         if not os.environ.get('GLUE_TESTING'):
             buttons = QMessageBox.Ok | QMessageBox.Cancel
-            dialog = QMessageBox.warning(self, "Confirm Close",
-                                         "Are you sure you want to close this tab? "
-                                         "This will close all data viewers in the tab.",
-                                         buttons=buttons,
-                                         defaultButton=QMessageBox.Cancel)
+            dialog = QMessageBox.warning(
+                self, "Confirm Close",
+                "Are you sure you want to close this tab? "
+                "This will close all data viewers in the tab.",
+                buttons=buttons, defaultButton=QMessageBox.Cancel)
             if not dialog == QMessageBox.Ok:
                 return
 
@@ -326,7 +326,7 @@ class GlueApplication(Application, QtGui.QMainWindow):
 
         Returns the window that this widget is wrapped in.
 
-        :param new_widget: new QtGui.QWidget to add
+        :param new_widget: new QtWidgets.QWidget to add
 
         :param label: label for the new window. Optional
         :type label: str
@@ -353,29 +353,9 @@ class GlueApplication(Application, QtGui.QMainWindow):
             new_widget.move(pos[0], pos[1])
         return sub
 
-    def set_setting(self, key, value):
-        """
-        Update a persistent setting in the application.
-
-        :param key: Name of a setting in the ``settings`` registry
-        :type key: str
-        :param value: New value for the setting
-        :type value: str
-        """
-        super(GlueApplication, self).set_setting(key, value)
-        settings = QtCore.QSettings('glue-viz', 'glue')
-        settings.setValue(key, value)
-
-    def _load_settings(self, path=None):
-        settings = QtCore.QSettings('glue-viz', 'glue')
-        for k, v in self.settings:
-            if settings.contains(k):
-                super(GlueApplication, self).set_setting(k, settings.value(k))
-
     def _edit_settings(self):
-        # save it to prevent garbage collection
-        self._editor = SettingsEditor(self)
-        self._editor.widget.show()
+        self._editor = PreferencesDialog(self)
+        self._editor.show()
 
     def gather_current_tab(self):
         """Arrange windows in current tab via tiling"""
@@ -384,11 +364,11 @@ class GlueApplication(Application, QtGui.QMainWindow):
     def _get_plot_dashboards(self, sub_window):
 
         if not isinstance(sub_window, GlueMdiSubWindow):
-            return QtGui.QWidget(), QtGui.QWidget(), ""
+            return QtWidgets.QWidget(), QtWidgets.QWidget(), ""
 
         widget = sub_window.widget()
         if not isinstance(widget, DataViewer):
-            return QtGui.QWidget(), QtGui.QWidget(), ""
+            return QtWidgets.QWidget(), QtWidgets.QWidget(), ""
 
         layer_view = widget.layer_view()
         options_widget = widget.options_widget()
@@ -401,7 +381,7 @@ class GlueApplication(Application, QtGui.QMainWindow):
                               (self._ui.plot_options, "Plot Options")]:
             layout = widget.layout()
             if layout is None:
-                layout = QtGui.QVBoxLayout()
+                layout = QtWidgets.QVBoxLayout()
                 layout.setContentsMargins(4, 4, 4, 4)
                 widget.setLayout(layout)
             while layout.count():
@@ -414,7 +394,8 @@ class GlueApplication(Application, QtGui.QMainWindow):
         if sub_window is None:
             return
 
-        layer_view, options_widget, title = self._get_plot_dashboards(sub_window)
+        layer_view, options_widget, title = self._get_plot_dashboards(
+            sub_window)
 
         layout = self._ui.plot_layers.layout()
         layout.addWidget(layer_view)
@@ -451,7 +432,7 @@ class GlueApplication(Application, QtGui.QMainWindow):
 
     def _create_menu(self):
         mbar = self.menuBar()
-        menu = QtGui.QMenu(mbar)
+        menu = QtWidgets.QMenu(mbar)
         menu.setTitle("&File")
 
         menu.addAction(self._actions['data_new'])
@@ -468,24 +449,25 @@ class GlueApplication(Application, QtGui.QMainWindow):
             for a in self._actions['session_export']:
                 submenu.addAction(a)
         menu.addSeparator()
-        menu.addAction("Edit &Settings", self._edit_settings)
+        menu.addAction("Edit &Preferences", self._edit_settings)
+        menu.addAction("&Quit", self.app.quit)
         mbar.addMenu(menu)
 
-        menu = QtGui.QMenu(mbar)
+        menu = QtWidgets.QMenu(mbar)
         menu.setTitle("&Edit ")
         menu.addAction(self._actions['undo'])
         menu.addAction(self._actions['redo'])
         mbar.addMenu(menu)
 
-        menu = QtGui.QMenu(mbar)
+        menu = QtWidgets.QMenu(mbar)
         menu.setTitle("&View ")
 
-        a = QtGui.QAction("&Console Log", menu)
+        a = QtWidgets.QAction("&Console Log", menu)
         a.triggered.connect(self._log._show)
         menu.addAction(a)
         mbar.addMenu(menu)
 
-        menu = QtGui.QMenu(mbar)
+        menu = QtWidgets.QMenu(mbar)
         menu.setTitle("&Canvas")
         menu.addAction(self._actions['tab_new'])
         menu.addAction(self._actions['viewer_new'])
@@ -494,19 +476,19 @@ class GlueApplication(Application, QtGui.QMainWindow):
         menu.addAction(self._actions['tab_rename'])
         mbar.addMenu(menu)
 
-        menu = QtGui.QMenu(mbar)
+        menu = QtWidgets.QMenu(mbar)
         menu.setTitle("Data &Manager")
         menu.addActions(self._layer_widget.actions())
 
         mbar.addMenu(menu)
 
-        menu = QtGui.QMenu(mbar)
+        menu = QtWidgets.QMenu(mbar)
         menu.setTitle("&Toolbars")
         tbar = EditSubsetModeToolBar()
         self._mode_toolbar = tbar
         self.addToolBar(tbar)
         tbar.hide()
-        a = QtGui.QAction("Selection Mode &Toolbar", menu)
+        a = QtWidgets.QAction("Selection Mode &Toolbar", menu)
         a.setCheckable(True)
         a.toggled.connect(tbar.setVisible)
         try:
@@ -518,7 +500,7 @@ class GlueApplication(Application, QtGui.QMainWindow):
         menu.addActions(tbar.actions())
         mbar.addMenu(menu)
 
-        menu = QtGui.QMenu(mbar)
+        menu = QtWidgets.QMenu(mbar)
         menu.setTitle("&Plugins")
         menu.addAction(self._actions['plugin_manager'])
         menu.addSeparator()
@@ -532,28 +514,29 @@ class GlueApplication(Application, QtGui.QMainWindow):
         # trigger inclusion of Mac Native "Help" tool
         menu = mbar.addMenu("&Help")
 
-        a = QtGui.QAction("&Online Documentation", menu)
+        a = QtWidgets.QAction("&Online Documentation", menu)
         a.triggered.connect(nonpartial(webbrowser.open, DOCS_URL))
         menu.addAction(a)
 
-        a = QtGui.QAction("Send &Feedback", menu)
-        a.triggered.connect(nonpartial(submit_bug_report))
+        a = QtWidgets.QAction("Send &Feedback", menu)
+        a.triggered.connect(nonpartial(submit_feedback))
         menu.addAction(a)
 
         menu.addSeparator()
         menu.addAction("Version information", show_glue_info)
 
-
     def _choose_load_data(self, data_importer=None):
         if data_importer is None:
             self.add_datasets(self.data_collection, data_wizard())
         else:
             data = data_importer()
             if not isinstance(data, list):
-                raise TypeError("Data loader should return list of Data objects")
+                raise TypeError("Data loader should return list of "
+                                "Data objects")
             for item in data:
                 if not isinstance(item, Data):
-                    raise TypeError("Data loader should return list of Data objects")
+                    raise TypeError("Data loader should return list of "
+                                    "Data objects")
             self.add_datasets(self.data_collection, data)
 
     def _create_actions(self):
@@ -561,39 +544,38 @@ class GlueApplication(Application, QtGui.QMainWindow):
         self._actions = {}
 
         a = action("&New Data Viewer", self,
-                tip="Open a new visualization window in the current tab",
-                shortcut=QtGui.QKeySequence.New
-                )
+                   tip="Open a new visualization window in the current tab",
+                   shortcut=QtGui.QKeySequence.New)
         a.triggered.connect(nonpartial(self.choose_new_data_viewer))
         self._actions['viewer_new'] = a
 
         a = action('New &Tab', self,
-                shortcut=QtGui.QKeySequence.AddTab,
-                tip='Add a new tab')
+                   shortcut=QtGui.QKeySequence.AddTab,
+                   tip='Add a new tab')
         a.triggered.connect(nonpartial(self.new_tab))
         self._actions['tab_new'] = a
 
         a = action('&Rename Tab', self,
-                shortcut="Ctrl+R",
-                tip='Set a new label for the current tab')
+                   shortcut="Ctrl+R",
+                   tip='Set a new label for the current tab')
         a.triggered.connect(nonpartial(self.tab_bar.rename_tab))
         self._actions['tab_rename'] = a
 
         a = action('&Gather Windows', self,
-                tip='Gather plot windows side-by-side',
-                shortcut='Ctrl+G')
+                   tip='Gather plot windows side-by-side',
+                   shortcut='Ctrl+G')
         a.triggered.connect(nonpartial(self.gather_current_tab))
         self._actions['gather'] = a
 
         a = action('&Save Session', self,
-                tip='Save the current session')
+                   tip='Save the current session')
         a.triggered.connect(nonpartial(self._choose_save_session))
         self._actions['session_save'] = a
 
         # Add file loader as first item in File menu for convenience. We then
         # also add it again below in the Import menu for consistency.
         a = action("&Open Data Set", self, tip="Open a new data set",
-                shortcut=QtGui.QKeySequence.Open)
+                   shortcut=QtGui.QKeySequence.Open)
         a.triggered.connect(nonpartial(self._choose_load_data,
                                        data_wizard))
         self._actions['data_new'] = a
@@ -624,8 +606,8 @@ class GlueApplication(Application, QtGui.QMainWindow):
             for e in exporters:
                 label, saver, checker, mode = e
                 a = action(label, self,
-                        tip='Export the current session to %s format' %
-                        label)
+                           tip='Export the current session to %s format' %
+                           label)
                 a.triggered.connect(nonpartial(self._choose_export_session,
                                                saver, checker, mode))
                 acts.append(a)
@@ -633,25 +615,25 @@ class GlueApplication(Application, QtGui.QMainWindow):
             self._actions['session_export'] = acts
 
         a = action('Open S&ession', self,
-                tip='Restore a saved session')
+                   tip='Restore a saved session')
         a.triggered.connect(nonpartial(self._restore_session))
         self._actions['session_restore'] = a
 
         a = action('Reset S&ession', self,
-                tip='Reset session to clean state')
+                   tip='Reset session to clean state')
         a.triggered.connect(nonpartial(self._reset_session))
         self._actions['session_reset'] = a
 
         a = action("Undo", self,
-                tip='Undo last action',
-                shortcut=QtGui.QKeySequence.Undo)
+                   tip='Undo last action',
+                   shortcut=QtGui.QKeySequence.Undo)
         a.triggered.connect(nonpartial(self.undo))
         a.setEnabled(False)
         self._actions['undo'] = a
 
         a = action("Redo", self,
-                tip='Redo last action',
-                shortcut=QtGui.QKeySequence.Redo)
+                   tip='Redo last action',
+                   shortcut=QtGui.QKeySequence.Redo)
         a.triggered.connect(nonpartial(self.redo))
         a.setEnabled(False)
         self._actions['redo'] = a
@@ -668,7 +650,7 @@ class GlueApplication(Application, QtGui.QMainWindow):
         self._actions['plugins'] = acts
 
         a = action('&Plugin Manager', self,
-                tip='Open plugin manager')
+                   tip='Open plugin manager')
         a.triggered.connect(nonpartial(self.plugin_manager))
         self._actions['plugin_manager'] = a
 
@@ -679,11 +661,11 @@ class GlueApplication(Application, QtGui.QMainWindow):
         from glue.config import qt_client
 
         if data and data.ndim == 1 and ScatterWidget in qt_client.members:
-            default = qt_client.members.index(ScatterWidget)
+            default = ScatterWidget
         elif data and data.ndim > 1 and ImageWidget in qt_client.members:
-            default = qt_client.members.index(ImageWidget)
+            default = ImageWidget
         else:
-            default = 0
+            default = None
 
         client = pick_class(list(qt_client.members), title='Data Viewer',
                             label="Choose a new data viewer",
@@ -694,7 +676,6 @@ class GlueApplication(Application, QtGui.QMainWindow):
 
     new_data_viewer = defer_draw(Application.new_data_viewer)
 
-    @set_cursor(Qt.WaitCursor)
     def _choose_save_session(self):
         """ Save the data collection and hub to file.
 
@@ -702,47 +683,52 @@ class GlueApplication(Application, QtGui.QMainWindow):
         """
 
         # include file filter twice, so it shows up in Dialog
-        outfile, file_filter = QtGui.QFileDialog.getSaveFileName(self,
-                                                                 filter="Glue Session (*.glu);; Glue Session including data (*.glu)")
+        outfile, file_filter = compat.getsavefilename(
+            parent=self, filters=("Glue Session (*.glu);; "
+                                  "Glue Session including data (*.glu)"))
 
         # This indicates that the user cancelled
         if not outfile:
             return
 
         # Add extension if not specified
-        if not '.' in outfile:
+        if '.' not in outfile:
             outfile += '.glu'
 
-        self.save_session(outfile, include_data="including data" in file_filter)
+        with set_cursor_cm(Qt.WaitCursor):
+            self.save_session(
+                outfile, include_data="including data" in file_filter)
 
     @messagebox_on_error("Failed to export session")
     def _choose_export_session(self, saver, checker, outmode):
         checker(self)
-        if outmode in ['file', 'directory']:
-            outfile, file_filter = QtGui.QFileDialog.getSaveFileName(self)
+        if outmode is None:
+            return saver(self)
+        elif outmode in ['file', 'directory']:
+            outfile, file_filter = compat.getsavefilename(parent=self)
             if not outfile:
                 return
             return saver(self, outfile)
         else:
             assert outmode == 'label'
-            label, ok = QtGui.QInputDialog.getText(self, 'Choose a label:',
-                                                   'Choose a label:')
+            label, ok = QtWidgets.QInputDialog.getText(self, 'Choose a label:',
+                                                       'Choose a label:')
             if not ok:
                 return
             return saver(self, label)
 
     @messagebox_on_error("Failed to restore session")
-    @set_cursor(Qt.WaitCursor)
     def _restore_session(self, show=True):
         """ Load a previously-saved state, and restart the session """
         fltr = "Glue sessions (*.glu)"
-        file_name, file_filter = QtGui.QFileDialog.getOpenFileName(self,
-                                                                   filter=fltr)
+        file_name, file_filter = compat.getopenfilename(
+            parent=self, filters=fltr)
         if not file_name:
             return
 
-        ga = self.restore_session(file_name)
-        self.close()
+        with set_cursor_cm(Qt.WaitCursor):
+            ga = self.restore_session(file_name)
+            self.close()
         return ga
 
     def _reset_session(self, show=True):
@@ -752,11 +738,11 @@ class GlueApplication(Application, QtGui.QMainWindow):
 
         if not os.environ.get('GLUE_TESTING'):
             buttons = QMessageBox.Ok | QMessageBox.Cancel
-            dialog = QMessageBox.warning(self, "Confirm Close",
-                                         "Are you sure you want to reset the session? "
-                                         "This will close all datasets, subsets, and data viewers",
-                                         buttons=buttons,
-                                         defaultButton=QMessageBox.Cancel)
+            dialog = QMessageBox.warning(
+                self, "Confirm Close",
+                "Are you sure you want to reset the session? "
+                "This will close all datasets, subsets, and data viewers",
+                buttons=buttons, defaultButton=QMessageBox.Cancel)
             if not dialog == QMessageBox.Ok:
                 return
 
@@ -802,7 +788,7 @@ class GlueApplication(Application, QtGui.QMainWindow):
         if hasattr(self, '_terminal_exception'):  # already failed to set up
             return
 
-        self._terminal_button = QtGui.QToolButton(self._ui)
+        self._terminal_button = QtWidgets.QToolButton(self._ui)
         self._terminal_button.setToolTip("Toggle IPython Prompt")
         i = get_icon('IPythonConsole')
         self._terminal_button.setIcon(i)
@@ -846,11 +832,13 @@ class GlueApplication(Application, QtGui.QMainWindow):
         if self._terminal.isVisible():
             self._hide_terminal()
             if self._terminal.isVisible():
-                warnings.warn("An unexpected error occurred while trying to hide the terminal")
+                warnings.warn("An unexpected error occurred while "
+                              "trying to hide the terminal")
         else:
             self._show_terminal()
             if not self._terminal.isVisible():
-                warnings.warn("An unexpected error occurred while trying to show the terminal")
+                warnings.warn("An unexpected error occurred while "
+                              "trying to show the terminal")
 
     def _hide_terminal(self):
         self._terminal.hide()
@@ -905,9 +893,21 @@ class GlueApplication(Application, QtGui.QMainWindow):
             event.ignore()
 
     def dropEvent(self, event):
+
         urls = event.mimeData().urls()
+
         for url in urls:
-            self.load_data(url.path())
+
+            # Get path to file
+            path = url.path()
+
+            # Workaround for a Qt bug that causes paths to start with a /
+            # on Windows: https://bugreports.qt.io/browse/QTBUG-46417
+            if sys.platform.startswith('win'):
+                if path.startswith('/') and path[2] == ':':
+                    path = path[1:]
+
+            self.load_data(path)
         event.accept()
 
     def report_error(self, message, detail):
@@ -967,24 +967,35 @@ class GlueApplication(Application, QtGui.QMainWindow):
     def _choose_merge(data, others):
 
         w = load_ui('merge.ui', None, directory=os.path.dirname(__file__))
+        w.button_yes.clicked.connect(w.accept)
+        w.button_no.clicked.connect(w.reject)
         w.show()
         w.raise_()
 
-        label = others[0].label if len(others) > 0 else data.label
+        # Add the main dataset to the list. Some of the 'others' may also be
+        # new ones, so it doesn't really make sense to distinguish between
+        # the two here. The main point is that some datasets, including at
+        # least one new one, have a common shape.
+        others.append(data)
+        others.sort(key=lambda x: x.label)
+
+        label = others[0].label
         w.merged_label.setText(label)
 
-        entries = [QtGui.QListWidgetItem(other.label) for other in others]
+        entries = [QtWidgets.QListWidgetItem(other.label) for other in others]
         for e in entries:
             e.setCheckState(Qt.Checked)
 
         for d, item in zip(others, entries):
             w.choices.addItem(item)
+
         if not w.exec_():
-            return None
+            return None, None
 
         result = [layer for layer, entry in zip(others, entries)
                   if entry.checkState() == Qt.Checked]
 
         if result:
-            result[0].label = str(w.merged_label.text())
-            return result + [data]
+            return result, str(w.merged_label.text())
+
+        return None, None
