@@ -12,11 +12,12 @@ Objects used to configure Glue at runtime.
 
 __all__ = ['Registry', 'SettingRegistry', 'ExporterRegistry',
            'ColormapRegistry', 'DataFactoryRegistry', 'QtClientRegistry',
-           'LinkFunctionRegistry', 'LinkHelperRegistry', 'QtToolRegistry',
+           'LinkFunctionRegistry', 'LinkHelperRegistry', 'ViewerToolRegistry',
            'SingleSubsetLayerActionRegistry', 'ProfileFitterRegistry',
            'qt_client', 'data_factory', 'link_function', 'link_helper',
            'colormaps', 'exporters', 'settings', 'fit_plugin',
-           'auto_refresh', 'importer', 'DictRegistry']
+           'auto_refresh', 'importer', 'DictRegistry', 'preference_panes',
+           'PreferencePanesRegistry']
 
 
 CFG_DIR = os.path.join(os.path.expanduser('~'), '.glue')
@@ -137,31 +138,101 @@ class SettingRegistry(DictRegistry):
     def __init__(self):
         super(SettingRegistry, self).__init__()
         self._validators = {}
+        self._defaults = {}
 
-    def add(self, key, value, validator=str):
-        self._members[key] = validator(value)
+    def add(self, key, default=None, validator=None):
+
+        if validator is None:
+            validator = lambda x: x
+
+        self._defaults[key] = validator(default)
         self._validators[key] = validator
 
     def __getattr__(self, attr):
         if attr.startswith('_'):
             raise AttributeError("No such setting: {0}".format(attr))
         else:
-            try:
+            if attr in self._members:
                 return self._members[attr]
-            except KeyError:
+            elif attr in self._defaults:
+                return self._defaults[attr]
+            else:
                 raise AttributeError("No such setting: {0}".format(attr))
 
     def __setattr__(self, attr, value):
         if attr.startswith('_'):
             object.__setattr__(self, attr, value)
-        elif attr in self._members:
+        elif attr in self:
             self._members[attr] = self._validators[attr](value)
         else:
             raise AttributeError("No such setting: {0}".format(attr))
 
+    def __dir__(self):
+        return sorted(self._members.keys())
+
+    def __contains__(self, setting):
+        return setting in self._defaults
+
     def __iter__(self):
-        for key in self._members:
-            yield key, self._members[key], self._validators[key]
+        for key in self._defaults:
+            value = self._members.get(key, self._defaults[key])
+            yield key, value, self._validators[key]
+
+    def reset_defaults(self):
+        self._members.clear()
+
+    def is_default(self, setting):
+        return setting in self._defaults and not setting in self._members
+
+
+class QGlueParserRegistry(Registry):
+    """
+    Registry for parsers that can be used to interpret arguments to the
+    :func:`~glue.qglue` function.
+
+    The members property is a list of parsers, each represented as a named tuple
+    with ``data_class``, ``parser`` and ``priority`` attributes, where ``class``
+    defines the class for which to use the parser, and ``parser`` is a function
+    that takes the input data and returns a list of glue
+    :class:`~glue.core.Data` objects. The ``parser`` functions should take two
+    arguments: the variable containing the data being parsed, and a label. In
+    addition, the priority (defaulting to 0) can be specified in case one wants
+    to make sure sub-classes get tested before more general classes. The
+    priority should be a numerical value, and the larger it is the higher the
+    priority.
+    """
+
+    item = namedtuple('DataFactory', 'data_class parser priority')
+
+    def add(self, data_class, parser, priority=0):
+        """
+        Add a new parser
+
+        Parameters
+        ----------
+        data_class : class
+            The type of of data for which to use the specified parser
+        parser : func
+            The function to use to parse the input data
+        priority : int, optional
+            The priority, which is used to determine the order in which to check
+            the parsers.
+        """
+        self.members.append(self.item(data_class, parser, priority))
+
+    def __call__(self, data_class, priority=0):
+        def adder(func):
+            if isinstance(data_class, tuple):
+                for dc in data_class:
+                    self.add(dc, func, priority=priority)
+            else:
+                self.add(data_class, func, priority=priority)
+            return func
+        return adder
+
+    def __iter__(self):
+        for member in sorted(self.members, key=lambda x: -x.priority):
+            yield member
 
 
 class DataImportRegistry(Registry):
@@ -218,6 +289,22 @@ class MenubarPluginRegistry(Registry):
         return adder
 
 
+class PreferencePanesRegistry(DictRegistry):
+    """
+    Stores preference panes
+
+    The members property is a list of tuples of Qt widget classes that can have
+    their own tab in the preferences window.
+    """
+
+    def add(self, label, widget_cls):
+        self._members[label] = widget_cls
+
+    def __iter__(self):
+        for label in self._members:
+            yield label, self._members[label]
+
+
 class ExporterRegistry(Registry):
 
     """Stores functions which can export an applocation to an output file
@@ -237,22 +324,27 @@ class ExporterRegistry(Registry):
       'label': exporter doesn't write to disk, but needs a label
     """
 
-    def add(self, label, exporter, checker, outmode='file'):
+    def add(self, label, exporter, checker, outmode=None):
         """
         Add a new exporter
-        :param label: Short label for the exporter
-        :type label: str
 
-        :param exporter: exporter function
-        :type exporter: function(application, path)
+        Parameters
+        ----------
+        label : str
+            Short label for the exporter
 
-        :param checker: function that checks if save is possible
-        :type exporter: function(application)
+        exporter : func
+            Exporter function which takes two arguments: the application and
+            optionally the path or label to create. This function should raise
+            an exception if export isn't possible.
 
-        ``exporter`` should raise an exception if export isn't possible.
+        checker : func
+            Function that checks if saving is possible, which takes one
+            argument: the application.
 
-        :param outmode: What kind of output is created?
-        :type outmode: str ('file' | 'directory' | 'label')
+        outmode : str or `None`
+            Indicates what kind of output is created. This can be either set to
+            ``'file'``, ``'directory'``, ``'label'``, or `None`.
         """
         self.members.append((label, exporter, checker, outmode))
 
@@ -351,29 +443,22 @@ class QtClientRegistry(Registry):
     """
 
 
-class QtToolRegistry(DictRegistry):
+class ViewerToolRegistry(DictRegistry):
 
-    def default_members(self):
-        defaults = {}
-        for viewer in qt_client.members:
-            try:
-                defaults[viewer] = viewer._get_default_tools()
-            except AttributeError:
-                logger.info("could not get default tools for {0}".format(viewer.__name__))
-                defaults[viewer] = []
-
-        return defaults
-
-    def add(self, tool_cls, widget_cls=None):
+    def add(self, tool_cls):
         """
-        Add a tool class to the registry, optionally specifying which widget
-        class it should apply to (``widget_cls``). if ``widget_cls`` is set
-        to `None`, the tool applies to all classes.
+        Add a tool class to the registry. The the ``tool_id`` attribute on the
+        tool_cls should be set, and is used by the viewers to indicate which
+        tools they want to
         """
-        if widget_cls in self.members:
-            self.members[widget_cls].append(tool_cls)
+        if tool_cls.tool_id in self.members:
+            raise ValueError("Tool ID '{0}' already registered".format(tool_cls.tool_id))
         else:
-            self.members[widget_cls] = [tool_cls]
+            self.members[tool_cls.tool_id] = tool_cls
+
+    def __call__(self, tool_cls):
+        self.add(tool_cls)
+        return tool_cls
 
 
 class LinkFunctionRegistry(Registry):
@@ -381,8 +466,10 @@ class LinkFunctionRegistry(Registry):
     """Stores functions to convert between quantities
 
     The members properety is a list of (function, info_string,
-    output_labels) namedtuples. `info_string` is describes what the
-    function does. `output_labels` is a list of names for each output.
+    output_labels) namedtuples. ``info_string`` describes what the
+    function does. ``output_labels`` is a list of names for each output.
+    ``category`` is a category in which the link funtion will appear (defaults
+    to 'General').
 
     New link functions can be registered via
 
@@ -393,18 +480,13 @@ class LinkFunctionRegistry(Registry):
 
     Link functions are expected to receive and return numpy arrays
     """
-    item = namedtuple('LinkFunction', 'function info output_labels')
+    item = namedtuple('LinkFunction', 'function info output_labels category')
 
-    def default_members(self):
-        from glue.core import link_helpers
-        return list(self.item(l, "", l.output_args)
-                    for l in link_helpers.__LINK_FUNCTIONS__)
-
-    def __call__(self, info="", output_labels=None):
+    def __call__(self, info="", output_labels=None, category='General'):
         out = output_labels or []
 
         def adder(func):
-            self.add(self.item(func, info, out))
+            self.add(self.item(func, info, out, category))
             return func
         return adder
 
@@ -431,7 +513,8 @@ class LinkHelperRegistry(Registry):
     The members property is a list of (object, info_string,
     input_labels) tuples. `Object` is the link helper. `info_string`
     describes what `object` does. `input_labels` is a list labeling
-    the inputs.
+    the inputs. ``category`` is a category in which the link funtion will appear
+    (defaults to 'General').
 
     Each link helper takes a list of ComponentIDs as inputs, and
     returns an iterable object (e.g. list) of ComponentLinks.
@@ -444,16 +527,11 @@ class LinkHelperRegistry(Registry):
             return [ComponentLink([degree], arcsecond, using=lambda d: d*3600),
                     ComponentLink([arcsecond], degree, using=lambda a: a/3600)]
     """
-    item = namedtuple('LinkHelper', 'helper info input_labels')
+    item = namedtuple('LinkHelper', 'helper info input_labels category')
 
-    def default_members(self):
-        from glue.core.link_helpers import __LINK_HELPERS__ as helpers
-        return list(self.item(l, l.info_text, l.input_args)
-                    for l in helpers)
-
-    def __call__(self, info, input_labels):
+    def __call__(self, info, input_labels, category='General'):
         def adder(func):
-            self.add(self.item(func, info, input_labels))
+            self.add(self.item(func, info, input_labels, category))
             return func
         return adder
 
@@ -487,7 +565,7 @@ class BooleanSetting(object):
         return self.state
 
 qt_client = QtClientRegistry()
-tool_registry = QtToolRegistry()
+viewer_tool = ViewerToolRegistry()
 data_factory = DataFactoryRegistry()
 link_function = LinkFunctionRegistry()
 link_helper = LinkHelperRegistry()
@@ -498,11 +576,14 @@ settings = SettingRegistry()
 fit_plugin = ProfileFitterRegistry()
 single_subset_action = SingleSubsetLayerActionRegistry()
 menubar_plugin = MenubarPluginRegistry()
+preference_panes = PreferencePanesRegistry()
+qglue_parser = QGlueParserRegistry()
 
 # watch loaded data files for changes?
 auto_refresh = BooleanSetting(False)
 enable_contracts = BooleanSetting(False)
 
+
 def load_configuration(search_path=None):
     ''' Find and import a config.py file
 
@@ -570,4 +651,8 @@ LIGHT_ORANGE = "#FDBF6F"
 LIGHT_PURPLE = "#CAB2D6"
 
 settings.add('SUBSET_COLORS', [RED, GREEN, BLUE, BROWN, ORANGE, PURPLE, PINK], validator=list)
-settings.add('DATA_COLOR', GRAY)
+settings.add('DATA_COLOR', '0.35')
+settings.add('DATA_ALPHA', 0.8, validator=float)
+settings.add('BACKGROUND_COLOR', '#FFFFFF')
+settings.add('FOREGROUND_COLOR', '#000000')
+settings.add('SHOW_LARGE_DATA_WARNING', True, validator=bool)
