@@ -10,14 +10,15 @@ import sys
 from shutil import copyfile
 
 import glue
+from glue.external.six import input
 
 
 def get_clobber():
     result = None
-    result = raw_input("\nDestination file exists. Overwrite? [y/n] ")
+    result = input("\nDestination file exists. Overwrite? [y/n] ")
     while result not in ['y', 'n']:
         print("\tPlease choose one of [y/n]")
-        result = raw_input("\nDestination file exists. Overwrite? [y/n] ")
+        result = input("\nDestination file exists. Overwrite? [y/n] ")
 
     return result == 'y'
 
@@ -26,7 +27,7 @@ def main():
 
     # Import at runtime because some tests change this value. We also don't
     # just import the function directly otherwise it is cached.
-    from . import config
+    from glue import config
     dest = config.CFG_DIR
 
     if not os.path.exists(dest):
