@@ -1,13 +1,19 @@
+from __future__ import absolute_import, division, print_function
+
 from .client import Client
+from .command import Command, CommandStack
+from .component import Component
+from .component_id import ComponentID
 from .component_link import ComponentLink
 from .coordinates import Coordinates
-from .data import Component, ComponentID, Data
+from .data import Data
 from .data_collection import DataCollection
 from .hub import Hub, HubListener
 from .link_manager import LinkManager
-from .subset import Subset
-from .visual import VisualAttributes
-from .command import Command, CommandStack
 from .session import Session
-from .application_base import Application
+from .subset import Subset
 from .subset_group import SubsetGroup
+from .visual import VisualAttributes
+
+# We import this last to avoid circular imports
+from .application_base import Application
