@@ -2,6 +2,7 @@ from __future__ import absolute_import, division, print_function
 
 from collections import OrderedDict
 
+import uuid
 import numpy as np
 import pandas as pd
 
@@ -27,7 +28,7 @@ from glue.utils import view_shape
 # they are here for backward-compatibility (the code used to live in this
 # file)
 from glue.core.component import Component, CoordinateComponent, DerivedComponent
-from glue.core.component_id import ComponentID, ComponentIDDict
+from glue.core.component_id import ComponentID, ComponentIDDict, PixelComponentID
 
 __all__ = ['Data']
 
@@ -100,6 +101,11 @@ class Data(object):
 
         self._key_joins = {}
 
+        # To avoid circular references when saving objects with references to
+        # the data, we make sure that all Data objects have a UUID that can
+        # uniquely identify them.
+        self.uuid = str(uuid.uuid4())
+
     @property
     def subsets(self):
         """
@@ -173,45 +179,165 @@ class Data(object):
               cid_other='cid_like')
     def join_on_key(self, other, cid, cid_other):
         """
-        Create an *element* mapping to another dataset, by
-        joining on values of ComponentIDs in both datasets.
+        Create an *element* mapping to another dataset, by joining on values of
+        ComponentIDs in both datasets.
 
-        This join allows any subsets defined on `other` to be
-        propagated to self.
+        This join allows any subsets defined on `other` to be propagated to
+        self. The different ways to call this method are described in the
+        **Examples** section below.
 
-        :param other: :class:`~glue.core.data.Data` to join with
-        :param cid: str or :class:`glue.core.component_id.ComponentID` in this dataset to use as a key
-        :param cid_other: ComponentID in the other dataset to use as a key
+        Parameters
+        ----------
+        other : :class:`~glue.core.data.Data`
+            Data object to join with
+        cid : str or :class:`~glue.core.component_id.ComponentID` or iterable
+            Component(s) in this dataset to use as a key
+        cid_other : str or :class:`~glue.core.component_id.ComponentID` or iterable
+            Component(s) in the other dataset to use as a key
 
-        :example:
+        Examples
+        --------
 
-        >>> d1 = Data(x=[1, 2, 3, 4, 5], k1=[0, 0, 1, 1, 2], label='d1')
-        >>> d2 = Data(y=[2, 4, 5, 8, 4], k2=[1, 3, 1, 2, 3], label='d2')
-        >>> d2.join_on_key(d1, 'k2', 'k1')
+        There are several ways to use this function, depending on how many
+        components are passed to ``cid`` and ``cid_other``.
 
-        >>> s = d1.new_subset()
-        >>> s.subset_state = d1.id['x'] > 2
-        >>> s.to_mask()
-        array([False, False,  True,  True,  True], dtype=bool)
+        **Joining on single components**
 
-        >>> s = d2.new_subset()
-        >>> s.subset_state = d1.id['x'] > 2
-        >>> s.to_mask()
-        array([ True, False,  True,  True, False], dtype=bool)
+        First, one can specify a single component ID for both ``cid`` and
+        ``cid_other``: this is the standard mode, and joins one component from
+        one dataset to the other:
 
-        The subset state selects the last 3 items in d1. These have
-        key values k1 of 1 and 2. Thus, the selected items in d2
-        are the elements where k2 = 1 or 2.
+            >>> d1 = Data(x=[1, 2, 3, 4, 5], k1=[0, 0, 1, 1, 2], label='d1')
+            >>> d2 = Data(y=[2, 4, 5, 8, 4], k2=[1, 3, 1, 2, 3], label='d2')
+            >>> d2.join_on_key(d1, 'k2', 'k1')
+
+        Selecting all values in ``d1`` where x is greater than 2 returns
+        the last three items as expected:
+
+            >>> s = d1.new_subset()
+            >>> s.subset_state = d1.id['x'] > 2
+            >>> s.to_mask()
+            array([False, False,  True,  True,  True], dtype=bool)
+
+        The linking was done between k1 and k2, and the values of
+        k1 for the last three items are 1 and 2 - this means that the
+        first, third, and fourth item in ``d2`` will then get selected,
+        since k2 has a value of either 1 or 2 for these items.
+
+            >>> s = d2.new_subset()
+            >>> s.subset_state = d1.id['x'] > 2
+            >>> s.to_mask()
+            array([ True, False,  True,  True, False], dtype=bool)
+
+        **Joining on multiple components**
+
+        .. note:: This mode is currently slow, and will be optimized
+                  significantly in future.
+
+        Next, one can specify several components for each dataset: in this
+        case, the number of components given should match for both datasets.
+        This causes items in both datasets to be linked when (and only when)
+        the set of keys match between the two datasets:
+
+            >>> d1 = Data(x=[1, 2, 3, 5, 5],
+            ...           y=[0, 0, 1, 1, 2], label='d1')
+            >>> d2 = Data(a=[2, 5, 5, 8, 4],
+            ...           b=[1, 3, 2, 2, 3], label='d2')
+            >>> d2.join_on_key(d1, ('a', 'b'), ('x', 'y'))
+
+        Selecting all items where x is 5 in ``d1`` in which x is a
+        component works as expected and selects the two last items::
+
+            >>> s = d1.new_subset()
+            >>> s.subset_state = d1.id['x'] == 5
+            >>> s.to_mask()
+            array([False, False, False,  True,  True], dtype=bool)
+
+        If we apply this selection to ``d2``, only items where a is 5
+        and b is 2 will be selected:
+
+            >>> s = d2.new_subset()
+            >>> s.subset_state = d1.id['x'] == 5
+            >>> s.to_mask()
+            array([False, False,  True, False, False], dtype=bool)
+
+        and in particular, the second item (where a is 5 and b is 3) is not
+        selected.
+
+        **One-to-many and many-to-one joining**
+
+        Finally, you can specify one component in one dataset and multiple ones
+        in the other. In the case where one component is specified for this
+        dataset and multiple ones for the other dataset, then when an item
+        is selected in the other dataset, it will cause any item in the present
+        dataset which matches any of the keys in the other data to be selected:
+
+            >>> d1 = Data(x=[1, 2, 3], label='d1')
+            >>> d2 = Data(a=[1, 1, 2],
+            ...           b=[2, 3, 3], label='d2')
+            >>> d1.join_on_key(d2, 'x', ('a', 'b'))
+
+        In this case, if we select all items in ``d2`` where a is 2, this
+        will select the third item:
+
+            >>> s = d2.new_subset()
+            >>> s.subset_state = d2.id['a'] == 2
+            >>> s.to_mask()
+            array([False, False,  True], dtype=bool)
+
+        Since we have joined the datasets using both a and b, we select
+        all items in ``d1`` where x is either the value or a or b
+        (2 or 3) which means we select the second and third item:
+
+            >>> s = d1.new_subset()
+            >>> s.subset_state = d2.id['a'] == 2
+            >>> s.to_mask()
+            array([False,  True,  True], dtype=bool)
+
+        We can also join the datasets the other way around:
+
+            >>> d1 = Data(x=[1, 2, 3], label='d1')
+            >>> d2 = Data(a=[1, 1, 2],
+            ...           b=[2, 3, 3], label='d2')
+            >>> d2.join_on_key(d1, ('a', 'b'), 'x')
+
+        In this case, selecting items in ``d1`` where x is 1 selects the
+        first item, as expected:
+
+            >>> s = d1.new_subset()
+            >>> s.subset_state = d1.id['x'] == 1
+            >>> s.to_mask()
+            array([ True, False, False], dtype=bool)
+
+        This then causes any item in ``d2`` where either a or b are 1
+        to be selected, i.e. the first two items:
+
+            >>> s = d2.new_subset()
+            >>> s.subset_state = d1.id['x'] == 1
+            >>> s.to_mask()
+            array([ True,  True, False], dtype=bool)
         """
-        _i1, _i2 = cid, cid_other
-        cid = self.find_component_id(cid)
-        cid_other = other.find_component_id(cid_other)
-        if cid is None:
-            raise ValueError("ComponentID not found in %s: %s" %
-                             (self.label, _i1))
-        if cid_other is None:
-            raise ValueError("ComponentID not found in %s: %s" %
-                             (other.label, _i2))
+
+        # To make things easier, we transform all component inputs to a tuple
+        if isinstance(cid, six.string_types) or isinstance(cid, ComponentID):
+            cid = (cid,)
+        if isinstance(cid_other, six.string_types) or isinstance(cid_other, ComponentID):
+            cid_other = (cid_other,)
+
+        if len(cid) > 1 and len(cid_other) > 1 and len(cid) != len(cid_other):
+            raise Exception("Either the number of components in the key join "
+                            "sets should match, or one of the component sets "
+                            "should contain a single component.")
+
+        def get_component_id(data, name):
+            cid = data.find_component_id(name)
+            if cid is None:
+                raise ValueError("ComponentID not found in %s: %s" %
+                                 (data.label, name))
+            return cid
+
+        cid = tuple(get_component_id(self, name) for name in cid)
+        cid_other = tuple(get_component_id(other, name) for name in cid_other)
 
         self._key_joins[other] = (cid, cid_other)
         other._key_joins[self] = (cid_other, cid)
@@ -312,7 +438,8 @@ class Data(object):
         for i in range(self.ndim):
             comp = CoordinateComponent(self, i)
             label = pixel_label(i, self.ndim)
-            cid = self.add_component(comp, "Pixel %s" % label, hidden=True)
+            cid = PixelComponentID(i, "Pixel Axis %s" % label, hidden=True)
+            self.add_component(comp, cid)
             self._pixel_component_ids.append(cid)
         if self.coords:
             for i in range(self.ndim):
@@ -576,8 +703,12 @@ class Data(object):
         s += "Number of dimensions: %i\n" % self.ndim
         s += "Shape: %s\n" % ' x '.join([str(x) for x in self.shape])
         s += "Components:\n"
-        for i, component in enumerate(self._components):
-            s += " %i) %s\n" % (i, component)
+        for i, cid in enumerate(self._components):
+            comp = self.get_component(cid)
+            if comp.units is None or comp.units == '':
+                s += " %i) %s\n" % (i, cid)
+            else:
+                s += " %i) %s [%s]\n" % (i, cid, comp.units)
         return s[:-1]
 
     def __repr__(self):
@@ -699,11 +830,75 @@ class Data(object):
         for subset in self.subsets:
             clear_cache(subset.subset_state.to_mask)
 
+    def update_values_from_data(self, data):
+        """
+        Replace numerical values in data to match values from another dataset.
+
+        Notes
+        -----
+
+        This method drops components that aren't present in the new data, and
+        adds components that are in the new data that were not in the original
+        data. The matching is done by component label, and components are
+        resized if needed. This means that for components with matching labels
+        in the original and new data, the
+        :class:`~glue.core.component_id.ComponentID` are preserved, and
+        existing plots and selections will be updated to reflect the new
+        values. Note that the coordinates are also copied, but the style is
+        **not** copied.
+        """
+
+        old_labels = [cid.label for cid in self.components]
+        new_labels = [cid.label for cid in data.components]
+
+        if len(old_labels) == len(set(old_labels)):
+            old_labels = set(old_labels)
+        else:
+            raise ValueError("Non-unique component labels in original data")
+
+        if len(new_labels) == len(set(new_labels)):
+            new_labels = set(new_labels)
+        else:
+            raise ValueError("Non-unique component labels in new data")
+
+        # Remove components that don't have a match in new data
+        for cname in old_labels - new_labels:
+            cid = self.find_component_id(cname)
+            self.remove_component(cid)
+
+        # Update shape
+        self._shape = data._shape
+
+        # Update components that exist in both
+        for cname in old_labels & new_labels:
+            comp_old = self.get_component(cname)
+            comp_new = data.get_component(cname)
+            comp_old._data = comp_new._data
+
+        # Add components that didn't exist in original one
+        for cname in new_labels - old_labels:
+            cid = data.find_component_id(cname)
+            comp_new = data.get_component(cname)
+            self.add_component(comp_new, cid)
+
+        # Update data label
+        self.label = data.label
+
+        # Update data coordinates
+        self.coords = data.coords
+
+        # alert hub of the change
+        if self.hub is not None:
+            msg = NumericalDataChangedMessage(self)
+            self.hub.broadcast(msg)
+
+        for subset in self.subsets:
+            clear_cache(subset.subset_state.to_mask)
+
 
 @contract(i=int, ndim=int)
 def pixel_label(i, ndim):
-    if ndim == 2:
-        return ['y', 'x'][i]
-    if ndim == 3:
-        return ['z', 'y', 'x'][i]
-    return "Axis %s" % i
+    label = "{0}".format(i)
+    if 1 <= ndim <= 3:
+        label += " [{0}]".format('xyz'[ndim - 1 - i])
+    return label
