@@ -3,7 +3,7 @@ from __future__ import absolute_import, division, print_function
 import copy
 
 import numpy as np
-from matplotlib.patches import Ellipse, Polygon, Rectangle, Path as mplPath
+from matplotlib.patches import Ellipse, Polygon, Rectangle, Path as MplPath, PathPatch
 from matplotlib.transforms import IdentityTransform, blended_transform_factory
 
 from glue.core.exceptions import UndefinedROI
@@ -1155,7 +1155,7 @@ class MplPathROI(MplPolygonalROI):
         else:
             x, y = self._roi.to_polygon()
             p = MplPath(np.column_stack((x, y)))
-            self._patch = PatchPath(p)
+            self._patch = PathPatch(p)
             self._patch.set_visible(True)
 
         # Update appearance
@@ -1219,14 +1219,15 @@ class CategoricalROI(Roi):
            within the ROI
 
         """
-
-        check = self._categorical_helper(x)
-        index = np.minimum(np.searchsorted(self.categories, check),
-                           len(self.categories) - 1)
-        return self.categories[index] == check
+        if self.categories is None or len(self.categories) == 0:
+            return np.zeros(x.shape, dtype=bool)
+        else:
+            check = self._categorical_helper(x)
+            index = np.minimum(np.searchsorted(self.categories, check),
+                               len(self.categories) - 1)
+            return self.categories[index] == check
 
     def update_categories(self, categories):
-
         self.categories = np.unique(self._categorical_helper(categories))
 
     def defined(self):
