@@ -55,6 +55,7 @@ from __future__ import absolute_import, division, print_function
 
 import os
 import json
+import uuid
 import types
 import logging
 from io import BytesIO
@@ -69,8 +70,10 @@ from matplotlib import cm
 
 from glue.external import six
 from glue import core
-from glue.core.data import (Data, Component, ComponentID, DerivedComponent,
-                            CoordinateComponent)
+from glue.core.data import Data
+from glue.core.component_id import ComponentID, PixelComponentID
+from glue.core.component import (Component, CategoricalComponent,
+                                 DerivedComponent, CoordinateComponent)
 from glue.core.subset import (OPSYM, SYMOP, CompositeSubsetState,
                               SubsetState, Subset, RoiSubsetState,
                               InequalitySubsetState, RangeSubsetState)
@@ -86,7 +89,11 @@ literals = tuple([type(None), float, int, bytes, bool, list, tuple])
 
 if six.PY2:
     literals += (long,)
-literals += (np.ScalarType,)
+
+
+literals += np.ScalarType
+
+
 
 # We need to make sure that we don't break backward-compatibility when we move
 # classes/functions around in Glue, so we have a file that maps the old paths to
@@ -251,7 +258,7 @@ class GlueSerializer(object):
         if isinstance(obj, six.string_types):
             return 'st__%s' % obj
 
-        if isinstance(obj, literals):
+        if type(obj) in literals:
             return obj
 
         oid = id(obj)
@@ -289,7 +296,7 @@ class GlueSerializer(object):
         if isinstance(obj, six.string_types):
             return 'st__' + obj
 
-        if isinstance(obj, literals):
+        if type(obj) in literals:
             return obj
 
         oid = id(obj)
@@ -303,6 +310,8 @@ class GlueSerializer(object):
 
         if isinstance(obj, types.FunctionType):
             result['_type'] = 'types.FunctionType'
+        elif isinstance(obj, types.MethodType):
+            result['_type'] = 'types.MethodType'
         else:
             result['_type'] = "%s.%s" % (type(obj).__module__,
                                          type(obj).__name__)
@@ -597,6 +606,13 @@ def _save_data_collection_2(dc, context):
     return result
 
 
+@saver(DataCollection, version=3)
+def _save_data_collection_3(dc, context):
+    result = _save_data_collection_2(dc, context)
+    result['subset_group_count'] = dc._sg_count
+    return result
+
+
 @loader(DataCollection)
 def _load_data_collection(rec, context):
     dc = DataCollection(list(map(context.object, rec['data'])))
@@ -614,6 +630,12 @@ def _load_data_collection_2(rec, context):
         grp.register_to_hub(result.hub)
     return result
 
+@loader(DataCollection, version=3)
+def _load_data_collection_3(rec, context):
+    result = _load_data_collection_2(rec, context)
+    result._sg_count = rec['subset_group_count']
+    return result
+
 
 @saver(Data)
 def _save_data(data, context):
@@ -693,6 +715,31 @@ def _load_data_3(rec, context):
                              for k, v0, v1 in rec['_key_joins'])
 
 
+@saver(Data, version=4)
+def _save_data_4(data, context):
+    result = _save_data_2(data, context)
+    def save_cid_tuple(cids):
+        return tuple(context.id(cid) for cid in cids)
+    result['_key_joins'] = [[context.id(k), save_cid_tuple(v0), save_cid_tuple(v1)]
+                            for k, (v0, v1) in data._key_joins.items()]
+    result['uuid'] = data.uuid
+    return result
+
+
+@loader(Data, version=4)
+def _load_data_4(rec, context):
+    result = _load_data_2(rec, context)
+    yield result
+    def load_cid_tuple(cids):
+        return tuple(context.object(cid) for cid in cids)
+    result._key_joins = dict((context.object(k), (load_cid_tuple(v0), load_cid_tuple(v1)))
+                             for k, v0, v1 in rec['_key_joins'])
+    if 'uuid' in rec and rec['uuid'] is not None:
+        result.uuid = rec['uuid']
+    else:
+        result.uuid = str(uuid.uuid4())
+
+
 @saver(ComponentID)
 def _save_component_id(cid, context):
     return dict(label=cid.label, hidden=cid.hidden)
@@ -703,6 +750,20 @@ def _load_component_id(rec, context):
     return ComponentID(rec['label'], rec['hidden'])
 
 
+@saver(PixelComponentID)
+def _save_component_id(cid, context):
+    return dict(axis=cid.axis, label=cid.label, hidden=cid.hidden)
+
+
+@loader(PixelComponentID)
+def _load_component_id(rec, context):
+    if 'axis' in rec:
+        axis = rec['axis']
+    else:  # backward-compatibility
+        axis = int(rec['label'].split()[2])
+    return PixelComponentID(axis, rec['label'], rec['hidden'])
+
+
 @saver(Component)
 def _save_component(component, context):
 
@@ -723,6 +784,29 @@ def _load_component(rec, context):
     return Component(data=context.object(rec['data']),
                      units=rec['units'])
 
+@saver(CategoricalComponent)
+def _save_categorical_component(component, context):
+
+    if not context.include_data and hasattr(component, '_load_log'):
+        log = component._load_log
+        return dict(log=context.id(log),
+                    log_item=log.id(component))
+
+    return dict(categorical_data=context.do(component.labels),
+                categories=context.do(component.categories),
+                jitter_method=context.do(component._jitter_method),
+                units=component.units)
+
+
+@loader(CategoricalComponent)
+def _load_categorical_component(rec, context):
+    if 'log' in rec:
+        return context.object(rec['log']).component(rec['log_item'])
+
+    return CategoricalComponent(categorical_data=context.object(rec['categorical_data']),
+                                categories=context.object(rec['categories']),
+                                jitter=context.object(rec['jitter_method']),
+                                units=rec['units'])
 
 @saver(DerivedComponent)
 def _save_derived_component(component, context):
@@ -792,6 +876,18 @@ def _load_function(rec, context):
     return lookup_class_with_patches(rec['function'])
 
 
+@saver(types.MethodType)
+def _save_method(method, context):
+    # Note: this only works for methods for which the class can be serialized
+    return {'instance': context.id(method.__self__), 'method': method.__name__}
+
+
+@loader(types.MethodType)
+def _load_method(rec, context):
+    instance = context.object(rec['instance'])
+    return getattr(instance, rec['method'])
+
+
 @saver(core.Session)
 def _save_session(session, context):
     # we will rely on GlueApplication to re-populate
