@@ -2,19 +2,21 @@
 
 from __future__ import absolute_import, division, print_function
 
+import warnings
 import operator
 
-import warnings
-from mock import MagicMock
 import pytest
 import numpy as np
+from mock import MagicMock
 
-from ..data import (Component, ComponentID, Data,
-                    DerivedComponent, CoordinateComponent,
-                    CategoricalComponent)
-from ... import core
-from ...tests.helpers import requires_astropy
-from ...external import six
+from glue.external import six
+from glue import core
+from glue.tests.helpers import requires_astropy
+
+from ..component import (Component, DerivedComponent, CoordinateComponent,
+                         CategoricalComponent)
+from ..component_id import ComponentID
+from ..data import Data
 
 
 VIEWS = (np.s_[:], np.s_[1], np.s_[::-1], np.s_[0, :])
@@ -79,22 +81,20 @@ class TestCategoricalComponent(object):
         self.array_data = np.array(self.list_data)
 
     def test_autodetection(self):
-        assert isinstance(Component.autotyped(self.array_data),
-                          CategoricalComponent)
-        assert isinstance(Component.autotyped(self.list_data),
-                          CategoricalComponent)
+        assert Component.autotyped(self.array_data).categorical
+        assert Component.autotyped(self.list_data).categorical
 
         x = np.array([True, False, True, False])
-        assert not isinstance(Component.autotyped(x), CategoricalComponent)
+        assert not Component.autotyped(x).categorical
 
         x = np.array([1, 2, 3, 4])
-        assert not isinstance(Component.autotyped(x), CategoricalComponent)
+        assert not Component.autotyped(x).categorical
 
         x = np.array(['1', '2', '3', '4'])
-        assert not isinstance(Component.autotyped(x), CategoricalComponent)
+        assert not Component.autotyped(x).categorical
 
         d = Data(x=['a', 'b', 'c'])
-        assert isinstance(d.get_component('x'), CategoricalComponent)
+        assert d.get_component('x').categorical
 
     def test_basic_properties(self):
         data = ['a', 'b', 'c', 'b', 'b', 'c', 'a', 'c', 'd']
@@ -330,10 +330,10 @@ def test_units():
 
     from astropy import units as u
 
-    comp = Component([1,2,3], units='m')
+    comp = Component([1, 2, 3], units='m')
     assert comp.units == 'm'
     assert isinstance(comp.units, six.string_types)
 
-    comp = Component([1,2,3], units=u.m)
+    comp = Component([1, 2, 3], units=u.m)
     assert comp.units == 'm'
     assert isinstance(comp.units, six.string_types)
