@@ -18,7 +18,9 @@ from ..exceptions import IncompatibleAttribute
 from ..hub import Hub
 from ..registry import Registry
 from ..subset import (Subset, CategoricalROISubsetState, SubsetState,
-                      RoiSubsetState, RangeSubsetState, AndState, OrState)
+                      RoiSubsetState, RangeSubsetState,
+                      CategoricalMultiRangeSubsetState,
+                      CategoricalROISubsetState2D, AndState)
 from ..roi import PolygonalROI, CategoricalROI, RangeROI, RectangularROI
 
 
@@ -398,7 +400,7 @@ class TestROICreation(object):
         y_comp = d.get_component(d.id['y'])
         roi = PolygonalROI([0, 0, 2, 2], [0, 2, 2, 0])
         s = x_comp.subset_from_roi('x', roi, other_comp=y_comp, other_att='y')
-        assert isinstance(s, OrState)
+        assert isinstance(s, CategoricalMultiRangeSubsetState)
 
         np.testing.assert_array_equal(s.to_mask(d), [True, True, False, False])
 
@@ -409,7 +411,7 @@ class TestROICreation(object):
         y_comp = d.get_component(d.id['y'])
         roi = PolygonalROI([0, 4, 4, 1, 0], [-0.5, 3.5, 0, -1, -0.5])
         s = x_comp.subset_from_roi('x', roi, other_comp=y_comp, other_att='y')
-        assert isinstance(s, OrState)
+        assert isinstance(s, CategoricalMultiRangeSubsetState)
 
         np.testing.assert_array_equal(s.to_mask(d), [True, False, True, False])
 
@@ -420,12 +422,12 @@ class TestROICreation(object):
         y_comp = d.get_component(d.id['y'])
         roi = RectangularROI(xmin=-0.1, xmax=2.1, ymin=-0.1, ymax=2.1)
         s = x_comp.subset_from_roi('x', roi, other_comp=y_comp, other_att='y')
-        assert isinstance(s, OrState)
+        assert isinstance(s, AndState)
 
         np.testing.assert_array_equal(s.to_mask(d), [True, True, False, False])
 
         s = y_comp.subset_from_roi('y', roi, other_comp=x_comp, other_att='x')
-        assert isinstance(s, OrState)
+        assert isinstance(s, AndState)
 
         np.testing.assert_array_equal(s.to_mask(d), [True, True, False, False])
 
@@ -436,7 +438,7 @@ class TestROICreation(object):
         y_comp = d.get_component(d.id['y'])
         roi = PolygonalROI([0.5, 1.5, 2.5, 1, 0.5], [0.5, 0.5, 2.5, 3.5, 0.5])
         s = x_comp.subset_from_roi('x', roi, other_comp=y_comp, other_att='y')
-        assert isinstance(s, OrState)
+        assert isinstance(s, CategoricalROISubsetState2D)
 
         np.testing.assert_array_equal(s.to_mask(d), [False, True, True, False, True, False])
 
@@ -447,7 +449,7 @@ class TestROICreation(object):
         y_comp = d.get_component(d.id['y'])
         roi = PolygonalROI([0.5, 0.6, 0.6, 0.5], [0.5, 0.5, 0.6, 0.5])
         s = x_comp.subset_from_roi('x', roi, other_comp=y_comp, other_att='y')
-        assert isinstance(s, SubsetState)
+        assert isinstance(s, CategoricalROISubsetState2D)
 
         np.testing.assert_array_equal(s.to_mask(d), [False, False, False, False, False, False])
 
@@ -476,13 +478,13 @@ def test_component_id_item_access_missing():
 class TestPixelLabel(object):
 
     def test(self):
-        assert pixel_label(0, 2) == "y"
-        assert pixel_label(1, 2) == "x"
-        assert pixel_label(0, 3) == "z"
-        assert pixel_label(1, 3) == "y"
-        assert pixel_label(2, 3) == "x"
-        assert pixel_label(1, 0) == "Axis 1"
-        assert pixel_label(1, 4) == "Axis 1"
+        assert pixel_label(0, 2) == "0 [y]"
+        assert pixel_label(1, 2) == "1 [x]"
+        assert pixel_label(0, 3) == "0 [z]"
+        assert pixel_label(1, 3) == "1 [y]"
+        assert pixel_label(2, 3) == "2 [x]"
+        assert pixel_label(1, 0) == "1"
+        assert pixel_label(1, 4) == "1"
 
 
 @pytest.mark.parametrize(('kwargs'),
@@ -557,7 +559,7 @@ Number of dimensions: 1
 Shape: 3
 Components:
  0) x
- 1) Pixel Axis 0
+ 1) Pixel Axis 0 [x]
  2) World 0
  3) y
 """.strip()
@@ -565,4 +567,36 @@ Components:
 def test_data_str():
     # Regression test for Data.__str__
     d = Data(x=[1,2,3], y=[2,3,4], label='mydata')
-    assert str(d) == EXPECTED_STR
\ No newline at end of file
+    assert str(d) == EXPECTED_STR
+
+
+def test_update_values_from_data():
+    d1 = Data(a=[1,2,3], b=[4,5,6], label='banana')
+    d2 = Data(b=[1,2,3,4], c=[5,6,7,8], label='apple')
+    d1a = d1.id['a']
+    d1b = d1.id['b']
+    d2b = d2.id['b']
+    d2c = d2.id['c']
+    d1.update_values_from_data(d2)
+    assert not d1a in d1.components
+    assert d1b in d1.components
+    assert not d2b in d1.components
+    assert d2c in d1.components
+    assert d1.shape == (4,)
+
+
+def test_update_values_from_data_invalid():
+
+    d1 = Data(a=[1,2,3], label='banana')
+    d1.add_component([3,4,5], 'a')
+    d2 = Data(b=[1,2,3,4], c=[5,6,7,8], label='apple')
+    with pytest.raises(ValueError) as exc:
+        d1.update_values_from_data(d2)
+    assert exc.value.args[0] == "Non-unique component labels in original data"
+
+    d1 = Data(a=[1,2,3], b=[4,5,6], label='banana')
+    d2 = Data(b=[1,2,3,4], label='apple')
+    d2.add_component([5,6,7,8], 'b')
+    with pytest.raises(ValueError) as exc:
+        d1.update_values_from_data(d2)
+    assert exc.value.args[0] == "Non-unique component labels in new data"
