@@ -8,22 +8,30 @@ __all__ = ['CallbackProperty', 'callback_property',
 
 
 class CallbackProperty(object):
-
-    """A property that callback functions can be added to.
+    """
+    A property that callback functions can be added to.
 
     When a callback property changes value, each callback function
     is called with information about the state change. Otherwise,
     callback properties behave just like normal instance variables.
 
-    CallbackProperties must be defined at the class level. Use
-    the helper function :func:`add_callback` to attach a callback to
-    a specific instance of a class with CallbackProperties
+    CallbackProperties must be defined at the class level. Use the helper
+    function :func:`~glue.external.echo.add_callback` to attach a callback to a
+    specific instance of a class with CallbackProperties.
+
+    Parameters
+    ----------
+    default
+        The initial value for the property.
+    getter : `func`, optional
+        Can be used to override the default getter
+    setter : `func`, optional
+        Can be used to override the default setter
+    docstring : str
+        A custom docstring for this property
     """
 
     def __init__(self, default=None, getter=None, setter=None, docstring=None):
-        """
-        :param default: The initial value for the property
-        """
         self._default = default
         self._callbacks = WeakKeyDictionary()
         self._2arg_callbacks = WeakKeyDictionary()
@@ -71,11 +79,20 @@ class CallbackProperty(object):
         return self
 
     def notify(self, instance, old, new):
-        """Call all callback functions with the current value
+        """
+        Call all callback functions with the current value
 
-        :param instance: The instance to consider
-        :param old: The old value of the property
-        :param new: The new value of the property
+        Parameters
+        ----------
+        instance
+            The instance to consider
+        old
+            The old value of the property
+        new
+            The new value of the property
+
+        Notes
+        -----
 
         Each callback will either be called using
         callback(new) or callback(old, new) depending
@@ -89,21 +106,31 @@ class CallbackProperty(object):
             cback(old, new)
 
     def disable(self, instance):
-        """Disable callbacks for a specific instance"""
+        """
+        Disable callbacks for a specific instance
+        """
         self._disabled[instance] = True
 
     def enable(self, instance):
-        """Enable previously-disabled callbacks for a specific instance"""
+        """
+        Enable previously-disabled callbacks for a specific instance
+        """
         self._disabled[instance] = False
 
     def add_callback(self, instance, func, echo_old=False):
-        """Add a callback to a specific instance that manages this property
+        """
+        Add a callback to a specific instance that manages this property
 
-        :param instance: Instance to bind the callback to
-        :param func: Callback function
-        :param echo_old: If true, the callback function will be invoked
-        with both the old and new values of the property, as func(old, new)
-        If False (the default), will be invoked as func(new)
+        Parameters
+        ----------
+        instance
+            Instance to bind the callback to
+        func : `func`
+            Callback function
+        echo_old : bool, optional
+            If `True`, the callback function will be invoked with both the old
+            and new values of the property, as func(old, new) If `False` (the
+            default), will be invoked as func(new)
         """
         if echo_old:
             self._2arg_callbacks.setdefault(instance, []).append(func)
@@ -111,10 +138,15 @@ class CallbackProperty(object):
             self._callbacks.setdefault(instance, []).append(func)
 
     def remove_callback(self, instance, func):
-        """Remove a previously-added callback
+        """
+        Remove a previously-added callback
 
-        :param instance: The instance to detach the callback from
-        :param func: The callback function to remove
+        Parameters
+        ----------
+        instance
+            The instance to detach the callback from
+        func : `func`
+            The callback function to remove
         """
         for cb in [self._callbacks, self._2arg_callbacks]:
             if instance not in cb:
@@ -129,17 +161,22 @@ class CallbackProperty(object):
 
 
 def add_callback(instance, prop, callback, echo_old=False):
-    """Attach a callback function to a property in an instance
+    """
+    Attach a callback function to a property in an instance
 
-    :param instance: Instance of a class with callback properties
+    Parameters
+    ----------
+    instance
+        Instance of a class with callback properties
+    prop : str
+        Name of callback property in `instance`
+    callback : `func`
+        Callback function
 
-    :param prop: Name of callback property in `instance`
-    :type prop: str
+    Examples
+    --------
 
-    :param callback: Callback function
-    :type callback: Callable
-
-    Example::
+    ::
 
         class Foo:
             bar = CallbackProperty(0)
@@ -158,15 +195,17 @@ def add_callback(instance, prop, callback, echo_old=False):
 
 
 def remove_callback(instance, prop, callback):
-    """Remove a callback function from a property in an instance
+    """
+    Remove a callback function from a property in an instance
 
-    :param instance: Instance of a class with callback properties
-
-    :param prop: Name of callback property in `instance`
-    :type prop: str
-
-    :param callback: Callback function
-    :type callback: Callable
+    Parameters
+    ----------
+    instance
+        Instance of a class with callback properties
+    prop : str
+        Name of callback property in `instance`
+    callback : `func`
+        Callback function
     """
     p = getattr(type(instance), prop)
     if not isinstance(p, CallbackProperty):
@@ -176,9 +215,10 @@ def remove_callback(instance, prop, callback):
 
 def callback_property(getter):
     """
-    A decorator to build a CallbackProperty,
-    by wrapping a getter method, similar to the use
-    of @property::
+    A decorator to build a CallbackProperty, by wrapping a getter method,
+    similar to the use of @property.
+
+    For example::
 
         class Foo(object):
             @callback_property
@@ -208,12 +248,17 @@ class delay_callback(object):
     This is a context manager. Within the context block, no callbacks
     will be issued. Each callback will be called once on exit
 
-    :param instance: An instance object with CallbackProperties
+    Parameters
+    ----------
+    instance
+        An instance object with CallbackProperties
+    props : str or iterable
+        One or more properties within instance to delay
 
-    :param props: One or more properties within instance to delay
-    :type prop: str
+    Examples
+    --------
 
-    Example::
+    ::
 
         with delay_callback(foo, 'bar', 'baz'):
             f.bar = 20
@@ -270,18 +315,24 @@ class delay_callback(object):
 
 @contextmanager
 def ignore_callback(instance, *props):
-    """Temporarily ignore any callbacks from one or more callback properties
+    """
+    Temporarily ignore any callbacks from one or more callback properties.
 
-    This is a context manager. Within the context block, no callbacks
-    will be issued. In contrast with delay_callback, no callbakcs
-    will be called on exiting the context manager
+    This is a context manager. Within the context block, no callbacks will be
+    issued. In contrast with :func:`delay_callback`, no callbakcs will be called
+    on exiting the context manager
 
-    :param instance: An instance object with CallbackProperties
+    Parameters
+    ----------
+    instance
+        An instance object with CallbackProperties
+    props : str
+         One or more properties within instance to delay
 
-    :param props: One or more properties within instance to delay
-    :type prop: str
+    Examples
+    --------
 
-    Example::
+    ::
 
         with ignore_callback(foo, 'bar', 'baz'):
                 f.bar = 20
