@@ -8,6 +8,11 @@ import optparse
 from glue import __version__
 from glue.logger import logger
 
+try:
+    from glue.utils.qt.decorators import die_on_error
+except ImportError:
+    from glue.utils.decorators import die_on_error
+
 
 def parse(argv):
     """ Parse argument list, check validity
@@ -53,6 +58,8 @@ def parse(argv):
                       help='use CONFIG as configuration file')
     parser.add_option('-v', '--verbose', action='store_true',
                       help="Increase the vebosity level", default=False)
+    parser.add_option('--no-maximized', action='store_true', dest='nomax',
+                      help="Do not start Glue maximized", default=False)
 
     err_msg = verify(parser, argv)
     if err_msg:
@@ -88,37 +95,6 @@ def verify(parser, argv):
     return err_msg
 
 
-def die_on_error(msg):
-    """Decorator that catches errors, displays a popup message, and quits"""
-    def decorator(func):
-        def wrapper(*args, **kwargs):
-            try:
-                return func(*args, **kwargs)
-            except Exception as e:
-
-                import traceback
-
-                # Make sure application has been started
-                from glue.external.qt import get_qapp
-                get_qapp()
-
-                from glue.utils.qt import QMessageBoxPatched as QMessageBox
-                m = "%s\n%s" % (msg, e)
-                detail = str(traceback.format_exc())
-                if len(m) > 500:
-                    detail = "Full message:\n\n%s\n\n%s" % (m, detail)
-                    m = m[:500] + '...'
-
-                qmb = QMessageBox(QMessageBox.Critical, "Error", m)
-                qmb.setDetailedText(detail)
-                qmb.show()
-                qmb.raise_()
-                qmb.exec_()
-                sys.exit(1)
-        return wrapper
-    return decorator
-
-
 @die_on_error("Error restoring Glue session")
 def restore_session(gluefile):
     """Load a .glu file and return a DataCollection, Hub tuple"""
@@ -129,7 +105,6 @@ def restore_session(gluefile):
 @die_on_error("Error reading data file")
 def load_data_files(datafiles):
     """Load data files and return a list of datasets"""
-    from glue.core.data_collection import DataCollection
     from glue.core.data_factories import auto_data, load_data
 
     datasets = []
@@ -143,17 +118,23 @@ def run_tests():
     test()
 
 
-def start_glue(gluefile=None, config=None, datafiles=None):
+def start_glue(gluefile=None, config=None, datafiles=None, maximized=True):
     """Run a glue session and exit
 
-    :param gluefile: An optional .glu file to restore
-    :type gluefile: str
+    Parameters
+    ----------
+    gluefile : str
+        An optional ``.glu`` file to restore.
 
-    :param config: An optional configuration file to use
-    :type config: str
+    config : str
+        An optional configuration file to use.
+
+    datafiles : str
+        An optional list of data files to load.
+
+    maximized : bool
+        Maximize screen on startup. Otherwise, use default size.
 
-    :param datafiles: An optional list of data files to load
-    :type datafiles: list of str
     """
     import glue
     from glue.app.qt import GlueApplication
@@ -165,7 +146,7 @@ def start_glue(gluefile=None, config=None, datafiles=None):
 
     datafiles = datafiles or []
 
-    data, hub = None, None
+    hub = None
 
     if gluefile is not None:
         app = restore_session(gluefile)
@@ -178,7 +159,7 @@ def start_glue(gluefile=None, config=None, datafiles=None):
     hub = data_collection.hub
 
     session = glue.core.Session(data_collection=data_collection, hub=hub)
-    ga = GlueApplication(session=session)
+    ga = GlueApplication(session=session, maximized=maximized)
 
     if datafiles:
         datasets = load_data_files(datafiles)
@@ -198,19 +179,20 @@ def execute_script(script):
     Provides a way for people with pre-installed binaries to use
     the glue library
     """
-    execfile(script)
+    with open(script) as fin:
+        exec(fin.read())
     sys.exit(0)
 
 
 def get_splash():
     """Instantiate a splash screen"""
-    from glue.external.qt import QtGui
-    from glue.external.qt.QtCore import Qt
+    from qtpy import QtGui, QtWidgets
+    from qtpy.QtCore import Qt
     import os
 
     pth = os.path.join(os.path.dirname(__file__), 'logo.png')
     pm = QtGui.QPixmap(pth)
-    splash = QtGui.QSplashScreen(pm, Qt.WindowStaysOnTopHint)
+    splash = QtWidgets.QSplashScreen(pm, Qt.WindowStaysOnTopHint)
     splash.show()
 
     return splash
@@ -225,10 +207,14 @@ def main(argv=sys.argv):
 
     logger.info("Input arguments: %s", sys.argv)
 
+    # Global keywords for Glue startup.
+    kwargs = {'config': opt.config,
+              'maximized': not opt.nomax}
+
     if opt.test:
         return run_tests()
     elif opt.restore:
-        start_glue(gluefile=args[0], config=opt.config)
+        start_glue(gluefile=args[0], **kwargs)
     elif opt.script:
         execute_script(args[0])
     else:
@@ -239,11 +225,11 @@ def main(argv=sys.argv):
         if has_py:
             execute_script(args[0])
         elif has_glu:
-            start_glue(gluefile=args[0], config=opt.config)
+            start_glue(gluefile=args[0], **kwargs)
         elif has_file or has_files:
-            start_glue(datafiles=args, config=opt.config)
+            start_glue(datafiles=args, **kwargs)
         else:
-            start_glue(config=opt.config)
+            start_glue(**kwargs)
 
 
 _loaded_plugins = set()
@@ -267,14 +253,15 @@ def load_plugins():
     # plugin, such as add items to various registries.
 
     import setuptools
-    logger.info("Loading external plugins using setuptools=={0}".format(setuptools.__version__))
+    logger.info("Loading external plugins using "
+                "setuptools=={0}".format(setuptools.__version__))
 
     from glue._plugin_helpers import iter_plugin_entry_points, PluginConfig
     config = PluginConfig.load()
 
     for item in iter_plugin_entry_points():
 
-        if not item.module_name in _installed_plugins:
+        if item.module_name not in _installed_plugins:
             _installed_plugins.add(item.name)
 
         if item.module_name in _loaded_plugins:
@@ -288,7 +275,8 @@ def load_plugins():
             function = item.load()
             function()
         except Exception as exc:
-            logger.info("Loading plugin {0} failed (Exception: {1})".format(item.name, exc))
+            logger.info("Loading plugin {0} failed "
+                        "(Exception: {1})".format(item.name, exc))
         else:
             logger.info("Loading plugin {0} succeeded".format(item.name))
             _loaded_plugins.add(item.module_name)
@@ -298,5 +286,12 @@ def load_plugins():
     except Exception as e:
         logger.warn("Failed to load plugin configuration")
 
+    # Reload the settings now that we have loaded plugins, since some plugins
+    # may have added some settings. Note that this will not re-read settings
+    # that were previously read.
+    from glue._settings_helpers import load_settings
+    load_settings()
+
+
 if __name__ == "__main__":
-    sys.exit(main(sys.argv))  # prama: no cover
+    sys.exit(main(sys.argv))  # pragma: no cover
