@@ -3,17 +3,15 @@ from __future__ import absolute_import, division, print_function
 import pytest
 import numpy as np
 
+pytest.importorskip('astropy')
+
 from glue.core import ComponentID
 from glue.core.tests.test_link_helpers import check_link, check_using
-from glue.tests.helpers import ASTROPY_GE_04_INSTALLED
+from glue.core.tests.test_state import clone
 
 from ..link_helpers import (Galactic_to_FK5, FK4_to_FK5, ICRS_to_FK5,
                             Galactic_to_FK4, ICRS_to_FK4, ICRS_to_Galactic)
 
-if not ASTROPY_GE_04_INSTALLED:
-    pytest.skip()
-
-
 # We now store for each class the expected result of the conversion of (45,50)
 # from the input frame to output frame and then from the output frame to the
 # input frame.
@@ -59,3 +57,10 @@ def test_conversion(conv_class, expected):
     check_using(result[1], (x, y), expected[0][1])
     check_using(result[2], (x, y), expected[1][0])
     check_using(result[3], (x, y), expected[1][1])
+
+    # Check that state saving works
+
+    check_using(clone(result[0]), (x, y), expected[0][0])
+    check_using(clone(result[1]), (x, y), expected[0][1])
+    check_using(clone(result[2]), (x, y), expected[1][0])
+    check_using(clone(result[3]), (x, y), expected[1][1])
