@@ -1,8 +1,9 @@
 def setup():
+    from .qt import mouse_modes
     try:
-        from .qt_widget import GingaWidget
+        from .qt.viewer_widget import GingaWidget
     except ImportError:
         raise ImportError("ginga is required")
     else:
-        from ...config import qt_client
+        from glue.config import qt_client
         qt_client.add(GingaWidget)
