@@ -3,7 +3,7 @@ from __future__ import absolute_import, division, print_function
 from mock import MagicMock
 
 from glue.external.echo import CallbackProperty
-from glue.external.qt import QtGui
+from qtpy import QtGui
 
 from ..helpers import process_dialog
 from ..colors import qt4_to_mpl_color, QColorBox, connect_color, QColormapCombo
