@@ -1,6 +1,8 @@
+from __future__ import absolute_import, division, print_function
+
+from glue.utils.qt import get_qapp
+
 from .. import QMessageBoxPatched as QMessageBox
-from ....qt import get_qapp
-from ....external.qt import QtGui
 
 
 def test_main():
