@@ -1,9 +1,12 @@
+from __future__ import absolute_import, division, print_function
+
 import pytest
 import numpy as np
 
-from ...external.six import string_types, PY2
+from glue.external.six import string_types, PY2
 
-from ..array import view_shape, coerce_numeric, stack_view, unique, shape_to_string, check_sorted
+from ..array import (view_shape, coerce_numeric, stack_view, unique,
+                     shape_to_string, check_sorted, pretty_number)
 
 
 @pytest.mark.parametrize(('before', 'ref_after', 'ref_indices'),
@@ -75,3 +78,29 @@ def test_stack_view(shape, views):
                          (([1, 3, 4, 3], False), ([1, 2, np.nan, 3], True), ([1, 3, 4, 4.1], True)))
 def test_check_sorted(array, is_sorted):
     assert check_sorted(array) is is_sorted
+
+
+class TestPrettyNumber(object):
+
+    def test_single(self):
+        assert pretty_number([1]) == ['1']
+        assert pretty_number([0]) == ['0']
+        assert pretty_number([-1]) == ['-1']
+        assert pretty_number([1.0001]) == ['1']
+        assert pretty_number([1.01]) == ['1.01']
+        assert pretty_number([1e-5]) == ['1.000e-05']
+        assert pretty_number([1e5]) == ['1.000e+05']
+        assert pretty_number([3.3]) == ['3.3']
+        assert pretty_number([1.]) == ['1']
+        assert pretty_number([1.200]) == ['1.2']
+
+    def test_large(self):
+        # Regression test or a bug that caused trailing zeros in exponent to
+        # be removed.
+        assert pretty_number([1e9]) == ['1.000e+09']
+        assert pretty_number([2e10]) == ['2.000e+10']
+        assert pretty_number([3e11]) == ['3.000e+11']
+
+    def test_list(self):
+        assert pretty_number([1, 2, 3.3, 1e5]) == ['1', '2', '3.3',
+                                                   '1.000e+05']
