@@ -9,7 +9,7 @@ from glue.external.modest_image import extract_matched_slices
 from glue.core.edit_subset_mode import EditSubsetMode
 from glue.core.callback_property import (
     callback_property, CallbackProperty)
-from glue.core.message import ComponentReplacedMessage
+from glue.core.message import ComponentReplacedMessage, SettingsChangeMessage
 from glue.core.roi import PolygonalROI
 from glue.core.subset import Subset, RoiSubsetState
 from glue.core.data import Data
@@ -18,7 +18,7 @@ from glue.core.layer_artist import LayerArtistContainer
 from glue.core.state import lookup_class_with_patches
 from glue.utils import defer_draw
 
-from glue.viewers.common.viz_client import VizClient, init_mpl
+from glue.viewers.common.viz_client import VizClient, init_mpl, update_appearance_from_settings
 from glue.viewers.scatter.layer_artist import ScatterLayerBase, ScatterLayerArtist
 
 from .layer_artist import (ImageLayerArtist, SubsetImageLayerArtist,
@@ -769,16 +769,28 @@ class MplImageClient(ImageClient):
         For the Matplotlib client, see if the view window has changed enough
         such that the images should be resampled
         """
+
         logging.getLogger(__name__).debug("check update")
+
+        # We need to make sure we reapply the aspect ratio manually here,
+        # because at this point, if the user has zoomed in to a region with a
+        # different aspect ratio than the original view, Matplotlib has not yet
+        # enforced computed the final limits. This is an issue if we have
+        # requested square pixels.
+        self.axes.apply_aspect()
+
         vw = _view_window(self._axes)
+
         if vw != self._view_window:
             logging.getLogger(__name__).debug("updating")
             self._update_and_redraw()
             self._view_window = vw
 
     def _update_and_redraw(self):
+
         self._update_data_plot()
         self._update_subset_plots()
+
         self._redraw()
 
     @requires_data
@@ -846,6 +858,23 @@ class MplImageClient(ImageClient):
             self._crosshairs.remove()
             self._crosshairs = None
 
+    def register_to_hub(self, hub):
+
+        super(MplImageClient, self).register_to_hub(hub)
+
+        def is_appearance_settings(msg):
+            return ('BACKGROUND_COLOR' in msg.settings
+                    or 'FOREGROUND_COLOR' in msg.settings)
+
+        hub.subscribe(self, SettingsChangeMessage,
+                      self._update_appearance_from_settings,
+                      filter=is_appearance_settings)
+
+    def _update_appearance_from_settings(self, message):
+        update_appearance_from_settings(self.axes)
+        self._redraw()
+
+
 
 def _2d_shape(shape, slc):
     """
